@@ -8,8 +8,8 @@ HEADER_SIZE = 4 + 1 + 1 + 1 + 1 + 16 + 4
 
 
 @dataclass
-class VBAN_VMRT_Packet_Data:
-    """Represents the structure of a VMRT data packet"""
+class VbanRtPacket:
+    """Represents the body of a VBAN RT data packet"""
 
     _voicemeeterType: bytes
     _reserved: bytes
@@ -187,7 +187,7 @@ class VBAN_VMRT_Packet_Data:
     def striplabels(self) -> tuple:
         """returns tuple of strip labels"""
         return tuple(
-            self._stripLabelUTF8c60[i : i + 60].decode("ascii").split("\x00")[0]
+            self._stripLabelUTF8c60[i : i + 60].decode().split("\x00")[0]
             for i in range(0, 480, 60)
         )
 
@@ -195,14 +195,14 @@ class VBAN_VMRT_Packet_Data:
     def buslabels(self) -> tuple:
         """returns tuple of bus labels"""
         return tuple(
-            self._busLabelUTF8c60[i : i + 60].decode("ascii").split("\x00")[0]
+            self._busLabelUTF8c60[i : i + 60].decode().split("\x00")[0]
             for i in range(0, 480, 60)
         )
 
 
 @dataclass
-class VBAN_VMRT_Packet_Header:
-    """Represents a RESPONSE RT PACKET header"""
+class VbanRtPacketHeader:
+    """Represents the header of VBAN RT data packet"""
 
     name = "Voicemeeter-RTP"
     vban: bytes = "VBAN".encode()
@@ -225,7 +225,7 @@ class VBAN_VMRT_Packet_Header:
 
 
 @dataclass
-class TextRequestHeader:
+class RequestHeader:
     """Represents a REQUEST RT PACKET header"""
 
     name: str
@@ -262,8 +262,8 @@ class TextRequestHeader:
 
 
 @dataclass
-class RegisterRTHeader:
-    """Represents a REGISTER RT PACKET header"""
+class SubscribeHeader:
+    """Represents a packet used to subscribe to the RT Packet Service"""
 
     name = "Register RTP"
     timeout = 15
